Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DiscoverResult ¶
type DiscoverResult struct {
IsNatted bool `json:"isNatted"`
MappingBehavior EndpointDependencyType `json:"mappingBehavior"`
FilteringBehavior EndpointDependencyType `json:"filteringBehavior"`
PortPreservation bool `json:"portPreservation"`
NATType string `json:"natType"`
ExternalIP string `json:"externalIP"`
}
DiscoverResult contains a set of results from Discover method.
type EndpointDependencyType ¶
type EndpointDependencyType uint8
EndpointDependencyType ...
const ( // EndpointIndependent means the behavior is independent of the endpoint's address or port EndpointIndependent EndpointDependencyType = iota // EndpointAddrDependent means the behavior is dependent on the endpoint's address EndpointAddrDependent // EndpointAddrPortDependent means the behavior is dependent on the endpoint's address and port EndpointAddrPortDependent // EndpointUndefined ... EndpointUndefined )
func (EndpointDependencyType) String ¶
func (t EndpointDependencyType) String() string
Click to show internal directories.
Click to hide internal directories.